#!/usr/bin/python3
import argparse
import sys

sys.path.append("../")
from lib import BuilderFactory
from lib import Utils
from lib.ComponentOption import ComponentOption



def get_main_options():
    parser = argparse.ArgumentParser()
    parser.add_argument('command', nargs=argparse.REMAINDER, help='Optional command and it\'s options', default='full')
    return parser


def handle_command(obj, command):
    parameter = None
    if len(command) == 0:
        cmd = 'full'
    else:
        cmd = command[0]
        parameter = " ".join(command[1:])

    try:
        func = getattr(obj, cmd)
    except AttributeError:
        Utils.log("Unknown command: %s" % cmd)
        sys.exit(1)
    if parameter:
        func(parameter)
    else:
        func()


def main(args):
    options = get_main_options()
    opts = options.parse_args(args[1:])
    component_option = ComponentOption()
    try:
        component_option.load_from_file("sbuild/config.yml")
    except FileNotFoundError:
        print("There is no sbuild/config.yml file, please check it.\n"
              "You probably forget to apply internal patches!\n")
        sys.exit(2)

    builder = BuilderFactory.get_builder(".", component_option.name, component_option.builder)

    handle_command(builder, opts.command)


if __name__ == "__main__":
    main(sys.argv)
